==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationFeature.js <==
var group__PkgClassificationFeature =
[
    [ "Feature_base", "classCGAL_1_1Classification_1_1Feature__base.html", [
      [ "name", "classCGAL_1_1Classification_1_1Feature__base.html#a663fef81a6ba90aeed8686aabbe29b19", null ],
      [ "set_name", "classCGAL_1_1Classification_1_1Feature__base.html#a4f73d831d3ebdb11262b530fb02a9de2", null ],
      [ "value", "classCGAL_1_1Classification_1_1Feature__base.html#a601e16c0026bd33f28fc8bfd68b30461", null ]
    ] ],
    [ "Feature_handle", "classCGAL_1_1Classification_1_1Feature__handle.html", null ],
    [ "Feature_set", "classCGAL_1_1Classification_1_1Feature__set.html", [
      [ "const_iterator", "classCGAL_1_1Classification_1_1Feature__set.html#af573e052fddaca288312b046eb0272fd", null ],
      [ "iterator", "classCGAL_1_1Classification_1_1Feature__set.html#a0da6c5f28c7bb5c73efc8a8de5a8ecb6", null ],
      [ "Feature_set", "classCGAL_1_1Classification_1_1Feature__set.html#a613933a88be42c85ff4bbb5ecaf6552f", null ],
      [ "add", "classCGAL_1_1Classification_1_1Feature__set.html#a2d7dc5beaa908425dcf000ed441aa4bf", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Feature__set.html#aba58c7f565bdcbe754269ef2951d52a3", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Feature__set.html#a7026c5f5eaeadf8f14cd6a2692d3623b", null ],
      [ "begin_parallel_additions", "classCGAL_1_1Classification_1_1Feature__set.html#ad7314df99b70f0cee9cd4a3a70a4a186", null ],
      [ "clear", "classCGAL_1_1Classification_1_1Feature__set.html#ac49c9165decae6769582c460bcbe7e36", null ],
      [ "end", "classCGAL_1_1Classification_1_1Feature__set.html#a12f8ee999e7d63b7ecccd4a3fe4c9003", null ],
      [ "end", "classCGAL_1_1Classification_1_1Feature__set.html#a81961dd52e886a766a1b586f579c4092", null ],
      [ "end_parallel_additions", "classCGAL_1_1Classification_1_1Feature__set.html#ad7a95c53e03a82384e308351cbed10da", null ],
      [ "operator[]", "classCGAL_1_1Classification_1_1Feature__set.html#ad190af1ce94aac3fdccca1b0790eae13", null ],
      [ "remove", "classCGAL_1_1Classification_1_1Feature__set.html#ae3642069b1c1fbf30111ecfa8bdd2ef2", null ],
      [ "size", "classCGAL_1_1Classification_1_1Feature__set.html#aa38682bb0dd5cea98873425989d0e6bc", null ]
    ] ],
    [ "feature_cast", "group__PkgClassificationFeature.html#gaf4b1504270f25061f63f05743a17e5d1", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationFeature.js <==
var group__PkgClassificationFeature =
[
    [ "CGAL::Classification::Feature_base", "classCGAL_1_1Classification_1_1Feature__base.html", [
      [ "name", "classCGAL_1_1Classification_1_1Feature__base.html#a787d987602e5067fcec30f40954d2deb", null ],
      [ "set_name", "classCGAL_1_1Classification_1_1Feature__base.html#a4f73d831d3ebdb11262b530fb02a9de2", null ],
      [ "value", "classCGAL_1_1Classification_1_1Feature__base.html#a601e16c0026bd33f28fc8bfd68b30461", null ]
    ] ],
    [ "CGAL::Classification::Feature_handle", "classCGAL_1_1Classification_1_1Feature__handle.html", null ],
    [ "CGAL::Classification::Feature_set", "classCGAL_1_1Classification_1_1Feature__set.html", [
      [ "const_iterator", "classCGAL_1_1Classification_1_1Feature__set.html#af573e052fddaca288312b046eb0272fd", null ],
      [ "iterator", "classCGAL_1_1Classification_1_1Feature__set.html#a0da6c5f28c7bb5c73efc8a8de5a8ecb6", null ],
      [ "Feature_set", "classCGAL_1_1Classification_1_1Feature__set.html#a613933a88be42c85ff4bbb5ecaf6552f", null ],
      [ "add", "classCGAL_1_1Classification_1_1Feature__set.html#a2d7dc5beaa908425dcf000ed441aa4bf", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Feature__set.html#a7026c5f5eaeadf8f14cd6a2692d3623b", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Feature__set.html#aba58c7f565bdcbe754269ef2951d52a3", null ],
      [ "begin_parallel_additions", "classCGAL_1_1Classification_1_1Feature__set.html#ad7314df99b70f0cee9cd4a3a70a4a186", null ],
      [ "clear", "classCGAL_1_1Classification_1_1Feature__set.html#ac49c9165decae6769582c460bcbe7e36", null ],
      [ "end", "classCGAL_1_1Classification_1_1Feature__set.html#a81961dd52e886a766a1b586f579c4092", null ],
      [ "end", "classCGAL_1_1Classification_1_1Feature__set.html#a12f8ee999e7d63b7ecccd4a3fe4c9003", null ],
      [ "end_parallel_additions", "classCGAL_1_1Classification_1_1Feature__set.html#ad7a95c53e03a82384e308351cbed10da", null ],
      [ "operator[]", "classCGAL_1_1Classification_1_1Feature__set.html#ad190af1ce94aac3fdccca1b0790eae13", null ],
      [ "remove", "classCGAL_1_1Classification_1_1Feature__set.html#ae3642069b1c1fbf30111ecfa8bdd2ef2", null ],
      [ "size", "classCGAL_1_1Classification_1_1Feature__set.html#aa38682bb0dd5cea98873425989d0e6bc", null ]
    ] ],
    [ "CGAL::Classification::feature_cast", "group__PkgClassificationFeature.html#ga6684bc9ebea9fe0adfa4adcdb5185816", null ]
];
